# travelwarning
Reisewarnungen OpenData Schnittstelle. Dies ist die Beschreibung für die Schnittstelle zum Zugriff auf die Daten des [Auswärtigen Amtes](https://www.auswaertiges-amt.de/de/) im Rahmen der [OpenData](https://www.auswaertiges-amt.de/de/open-data-schnittstelle/736118) Initiative.
## Deaktivierung
Die Schnittstelle kann deaktiviert werden, in dem Fall wird ein leeres JSON-Objekt zurückgegeben.
## Fehlerfall
Im Fehlerfall wird ein leeres JSON-Objekt zurückgegeben.
## Nutzungsbedingungen
Die Nutzungsbedingungen sind auf der [OpenData-Schnittstelle](https://www.auswaertiges-amt.de/de/open-data-schnittstelle/736118)
 des Auswärtigen Amtes zu finden. 

## Änderungen [(offizielles Changelog)](https://www.auswaertiges-amt.de/de/-/2412916)
### version [1.2.6](https://www.auswaertiges-amt.de/de/-/2412916) - (08.12.2021)
Es werden zusätzlich zu jedem Land **Ländercodes** mit jeweils **zwei Buchstaben** mit ausgegeben.

Die Länderkürzel werden bei [`/travelwarning`](#operations-default-getTravelwarning) und [`/travelwarning/{contentId}`](#operations-default-getSingleTravelwarning) in einem neuen Attribut ausgegeben z.B. in: [`/travelwarning/199124`](https://www.auswaertiges-amt.de/opendata/travelwarning/199124).
### version [1.2.5](https://www.auswaertiges-amt.de/de/-/2412916) (ursprünglich geplant für Ende September 2021)
`content` (-> Details des Reise- und Sicherheitshinweis) wurde von [`/travelwarning`](#operations-default-getTravelwarning) entfernt -> bitte ab jetzt [`/travelwarning/{contentId}`](#operations-default-getSingleTravelwarning) nutzen um `content` abzufragen

`flagURL` (-> Details des Reise- und Sicherheitshinweis) wurde entfernt -> es werden keine **Flaggen** mehr angeboten

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.2.6
- Package version: 0.1.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

```sh
pip install deutschland[travelwarning]
```

### poetry install

```sh
poetry add deutschland -E travelwarning
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

## Usage

Import the package:
```python
from deutschland import travelwarning
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
from deutschland import travelwarning
from pprint import pprint
from deutschland.travelwarning.api import default_api
from deutschland.travelwarning.model.response_address import ResponseAddress
from deutschland.travelwarning.model.response_download import ResponseDownload
from deutschland.travelwarning.model.response_warning import ResponseWarning
from deutschland.travelwarning.model.response_warnings import ResponseWarnings
# Defining the host is optional and defaults to https://www.auswaertiges-amt.de/opendata
# See configuration.py for a list of all supported configuration parameters.
configuration = travelwarning.Configuration(
    host = "https://www.auswaertiges-amt.de/opendata"
)



# Enter a context with an instance of the API client
with travelwarning.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = default_api.DefaultApi(api_client)
    
    try:
        # Gibt die Merkblätter des Gesundheitsdienstes zurück
        api_response = api_instance.get_healthcare()
        pprint(api_response)
    except travelwarning.ApiException as e:
        print("Exception when calling DefaultApi->get_healthcare: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://www.auswaertiges-amt.de/opendata*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**get_healthcare**](docs/DefaultApi.md#get_healthcare) | **GET** /healthcare | Gibt die Merkblätter des Gesundheitsdienstes zurück
*DefaultApi* | [**get_representatives_country**](docs/DefaultApi.md#get_representatives_country) | **GET** /representativesInCountry | Gibt eine Liste der deutschen Vertretungen im Ausland zurück
*DefaultApi* | [**get_representatives_germany**](docs/DefaultApi.md#get_representatives_germany) | **GET** /representativesInGermany | Gibt eine Liste der ausländischen Vertretungen in Deutschland zurück
*DefaultApi* | [**get_single_travelwarning**](docs/DefaultApi.md#get_single_travelwarning) | **GET** /travelwarning/{contentId} | Gibt einen Reise- und Sicherheitshinweis zurück
*DefaultApi* | [**get_state_names**](docs/DefaultApi.md#get_state_names) | **GET** /stateNames | Gibt das Verzeichnis der Staatennamen zurück
*DefaultApi* | [**get_travelwarning**](docs/DefaultApi.md#get_travelwarning) | **GET** /travelwarning | Gibt alle Reise- und Sicherheitshinweise zurück


## Documentation For Models

 - [AdressListe](docs/AdressListe.md)
 - [Adresse](docs/Adresse.md)
 - [Artikel](docs/Artikel.md)
 - [Download](docs/Download.md)
 - [Reisewarnung](docs/Reisewarnung.md)
 - [ReisewarnungZusammenfassung](docs/ReisewarnungZusammenfassung.md)
 - [ResponseAddress](docs/ResponseAddress.md)
 - [ResponseAddressResponse](docs/ResponseAddressResponse.md)
 - [ResponseArtikel](docs/ResponseArtikel.md)
 - [ResponseArtikelResponse](docs/ResponseArtikelResponse.md)
 - [ResponseDownload](docs/ResponseDownload.md)
 - [ResponseDownloadResponse](docs/ResponseDownloadResponse.md)
 - [ResponseWarning](docs/ResponseWarning.md)
 - [ResponseWarningResponse](docs/ResponseWarningResponse.md)
 - [ResponseWarnings](docs/ResponseWarnings.md)
 - [ResponseWarningsResponse](docs/ResponseWarningsResponse.md)


## Documentation For Authorization

 All endpoints do not require authorization.

## Author

kontakt@bund.dev


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in travelwarning.apis and travelwarning.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from deutschland.travelwarning.api.default_api import DefaultApi`
- `from deutschland.travelwarning.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
from deutschland import travelwarning
from deutschland.travelwarning.apis import *
from deutschland.travelwarning.models import *
```

